from setuptools import setup

setup(name='psb_probability',
      version='1.2',
      description='Gaussian and Binomial distributions',
      packages=['psb_probability'],
      author = 'Prince Singh Bhadauria',
      author_email = 'princesinghbhadauria@gmail.com',
      zip_safe=False)
